# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200158ResponseServers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'iqn': 'str',
        'iscsi_ip': 'str',
        'ipsec_iscsi': 'str',
        'ipsec_nfs': 'str',
        'status': 'str',
        'os': 'str',
        'registered': 'str',
        'last_check_time': 'str',
        'last_state_change_time': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'iqn': 'iqn',
        'iscsi_ip': 'iscsi_ip',
        'ipsec_iscsi': 'ipsec_iscsi',
        'ipsec_nfs': 'ipsec_nfs',
        'status': 'status',
        'os': 'os',
        'registered': 'registered',
        'last_check_time': 'last_check_time',
        'last_state_change_time': 'last_state_change_time',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, iqn=None, iscsi_ip=None, ipsec_iscsi=None, ipsec_nfs=None, status=None, os=None, registered=None, last_check_time=None, last_state_change_time=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse200158ResponseServers - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._iqn = None
        self._iscsi_ip = None
        self._ipsec_iscsi = None
        self._ipsec_nfs = None
        self._status = None
        self._os = None
        self._registered = None
        self._last_check_time = None
        self._last_state_change_time = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if iqn is not None:
            self.iqn = iqn
        if iscsi_ip is not None:
            self.iscsi_ip = iscsi_ip
        if ipsec_iscsi is not None:
            self.ipsec_iscsi = ipsec_iscsi
        if ipsec_nfs is not None:
            self.ipsec_nfs = ipsec_nfs
        if status is not None:
            self.status = status
        if os is not None:
            self.os = os
        if registered is not None:
            self.registered = registered
        if last_check_time is not None:
            self.last_check_time = last_check_time
        if last_state_change_time is not None:
            self.last_state_change_time = last_state_change_time
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The name of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200158ResponseServers.


        :param name: The name of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                name is not None and not re.search(r'^srv-[0-9a-f]{8}$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^srv-[0-9a-f]{8}$/`")  # noqa: E501

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The display_name of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200158ResponseServers.


        :param display_name: The display_name of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def iqn(self):
        """Gets the iqn of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The iqn of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._iqn

    @iqn.setter
    def iqn(self, iqn):
        """Sets the iqn of this InlineResponse200158ResponseServers.


        :param iqn: The iqn of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._iqn = iqn

    @property
    def iscsi_ip(self):
        """Gets the iscsi_ip of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The iscsi_ip of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_ip

    @iscsi_ip.setter
    def iscsi_ip(self, iscsi_ip):
        """Sets the iscsi_ip of this InlineResponse200158ResponseServers.


        :param iscsi_ip: The iscsi_ip of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._iscsi_ip = iscsi_ip

    @property
    def ipsec_iscsi(self):
        """Gets the ipsec_iscsi of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The ipsec_iscsi of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._ipsec_iscsi

    @ipsec_iscsi.setter
    def ipsec_iscsi(self, ipsec_iscsi):
        """Sets the ipsec_iscsi of this InlineResponse200158ResponseServers.


        :param ipsec_iscsi: The ipsec_iscsi of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._ipsec_iscsi = ipsec_iscsi

    @property
    def ipsec_nfs(self):
        """Gets the ipsec_nfs of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The ipsec_nfs of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._ipsec_nfs

    @ipsec_nfs.setter
    def ipsec_nfs(self, ipsec_nfs):
        """Sets the ipsec_nfs of this InlineResponse200158ResponseServers.


        :param ipsec_nfs: The ipsec_nfs of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._ipsec_nfs = ipsec_nfs

    @property
    def status(self):
        """Gets the status of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The status of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200158ResponseServers.


        :param status: The status of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def os(self):
        """Gets the os of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The os of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this InlineResponse200158ResponseServers.


        :param os: The os of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._os = os

    @property
    def registered(self):
        """Gets the registered of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The registered of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._registered

    @registered.setter
    def registered(self, registered):
        """Sets the registered of this InlineResponse200158ResponseServers.


        :param registered: The registered of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._registered = registered

    @property
    def last_check_time(self):
        """Gets the last_check_time of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The last_check_time of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._last_check_time

    @last_check_time.setter
    def last_check_time(self, last_check_time):
        """Sets the last_check_time of this InlineResponse200158ResponseServers.


        :param last_check_time: The last_check_time of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._last_check_time = last_check_time

    @property
    def last_state_change_time(self):
        """Gets the last_state_change_time of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The last_state_change_time of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._last_state_change_time

    @last_state_change_time.setter
    def last_state_change_time(self, last_state_change_time):
        """Sets the last_state_change_time of this InlineResponse200158ResponseServers.


        :param last_state_change_time: The last_state_change_time of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._last_state_change_time = last_state_change_time

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The created_at of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200158ResponseServers.


        :param created_at: The created_at of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200158ResponseServers.  # noqa: E501


        :return: The modified_at of this InlineResponse200158ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200158ResponseServers.


        :param modified_at: The modified_at of this InlineResponse200158ResponseServers.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200158ResponseServers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200158ResponseServers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200158ResponseServers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class Compute(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_uuid': 'str',
        'cluster_ip': 'str',
        'cluster_url': 'str',
        'cluster_name': 'str',
        'cluster_storage_type': 'str',
        'cluster_version': 'str'
    }

    attribute_map = {
        'cluster_uuid': 'cluster_uuid',
        'cluster_ip': 'cluster_ip',
        'cluster_url': 'cluster_url',
        'cluster_name': 'cluster_name',
        'cluster_storage_type': 'cluster_storage_type',
        'cluster_version': 'cluster_version'
    }

    def __init__(self, cluster_uuid=None, cluster_ip=None, cluster_url=None, cluster_name=None, cluster_storage_type=None, cluster_version=None, _configuration=None):  # noqa: E501
        """Compute - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cluster_uuid = None
        self._cluster_ip = None
        self._cluster_url = None
        self._cluster_name = None
        self._cluster_storage_type = None
        self._cluster_version = None
        self.discriminator = None

        if cluster_uuid is not None:
            self.cluster_uuid = cluster_uuid
        if cluster_ip is not None:
            self.cluster_ip = cluster_ip
        if cluster_url is not None:
            self.cluster_url = cluster_url
        if cluster_name is not None:
            self.cluster_name = cluster_name
        if cluster_storage_type is not None:
            self.cluster_storage_type = cluster_storage_type
        if cluster_version is not None:
            self.cluster_version = cluster_version

    @property
    def cluster_uuid(self):
        """Gets the cluster_uuid of this Compute.  # noqa: E501

        The UUID of the cluster.  # noqa: E501

        :return: The cluster_uuid of this Compute.  # noqa: E501
        :rtype: str
        """
        return self._cluster_uuid

    @cluster_uuid.setter
    def cluster_uuid(self, cluster_uuid):
        """Sets the cluster_uuid of this Compute.

        The UUID of the cluster.  # noqa: E501

        :param cluster_uuid: The cluster_uuid of this Compute.  # noqa: E501
        :type: str
        """

        self._cluster_uuid = cluster_uuid

    @property
    def cluster_ip(self):
        """Gets the cluster_ip of this Compute.  # noqa: E501

        The IP address of the cluster.  # noqa: E501

        :return: The cluster_ip of this Compute.  # noqa: E501
        :rtype: str
        """
        return self._cluster_ip

    @cluster_ip.setter
    def cluster_ip(self, cluster_ip):
        """Sets the cluster_ip of this Compute.

        The IP address of the cluster.  # noqa: E501

        :param cluster_ip: The cluster_ip of this Compute.  # noqa: E501
        :type: str
        """

        self._cluster_ip = cluster_ip

    @property
    def cluster_url(self):
        """Gets the cluster_url of this Compute.  # noqa: E501

        The URL of the cluster.  # noqa: E501

        :return: The cluster_url of this Compute.  # noqa: E501
        :rtype: str
        """
        return self._cluster_url

    @cluster_url.setter
    def cluster_url(self, cluster_url):
        """Sets the cluster_url of this Compute.

        The URL of the cluster.  # noqa: E501

        :param cluster_url: The cluster_url of this Compute.  # noqa: E501
        :type: str
        """

        self._cluster_url = cluster_url

    @property
    def cluster_name(self):
        """Gets the cluster_name of this Compute.  # noqa: E501

        The name of the cluster.  # noqa: E501

        :return: The cluster_name of this Compute.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """Sets the cluster_name of this Compute.

        The name of the cluster.  # noqa: E501

        :param cluster_name: The cluster_name of this Compute.  # noqa: E501
        :type: str
        """

        self._cluster_name = cluster_name

    @property
    def cluster_storage_type(self):
        """Gets the cluster_storage_type of this Compute.  # noqa: E501

        The storage type of the cluster.  # noqa: E501

        :return: The cluster_storage_type of this Compute.  # noqa: E501
        :rtype: str
        """
        return self._cluster_storage_type

    @cluster_storage_type.setter
    def cluster_storage_type(self, cluster_storage_type):
        """Sets the cluster_storage_type of this Compute.

        The storage type of the cluster.  # noqa: E501

        :param cluster_storage_type: The cluster_storage_type of this Compute.  # noqa: E501
        :type: str
        """
        allowed_values = ["vpsa", "readonly", "vsc"]  # noqa: E501
        if (self._configuration.client_side_validation and
                cluster_storage_type not in allowed_values):
            raise ValueError(
                "Invalid value for `cluster_storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(cluster_storage_type, allowed_values)
            )

        self._cluster_storage_type = cluster_storage_type

    @property
    def cluster_version(self):
        """Gets the cluster_version of this Compute.  # noqa: E501

        The version of the cluster.  # noqa: E501

        :return: The cluster_version of this Compute.  # noqa: E501
        :rtype: str
        """
        return self._cluster_version

    @cluster_version.setter
    def cluster_version(self, cluster_version):
        """Sets the cluster_version of this Compute.

        The version of the cluster.  # noqa: E501

        :param cluster_version: The cluster_version of this Compute.  # noqa: E501
        :type: str
        """

        self._cluster_version = cluster_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Compute, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Compute):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Compute):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.vpsa_api import VPSAApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestVPSAApi(unittest.TestCase):
    """VPSAApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.vpsa_api.VPSAApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_drives(self):
        """Test case for add_drives

        """
        pass

    def test_add_virtual_network_interface(self):
        """Test case for add_virtual_network_interface

        """
        pass

    def test_add_vpsa_endpoints_conf_for_upload_types(self):
        """Test case for add_vpsa_endpoints_conf_for_upload_types

        """
        pass

    def test_allocate_networks_for_vpsa(self):
        """Test case for allocate_networks_for_vpsa

        """
        pass

    def test_assign_public_ip(self):
        """Test case for assign_public_ip

        """
        pass

    def test_cancel_failover(self):
        """Test case for cancel_failover

        """
        pass

    def test_cancel_scheduled_zsnap(self):
        """Test case for cancel_scheduled_zsnap

        """
        pass

    def test_cancel_upgrade(self):
        """Test case for cancel_upgrade

        """
        pass

    def test_change_cache(self):
        """Test case for change_cache

        """
        pass

    def test_create_new_vpsa_upload_endpoint(self):
        """Test case for create_new_vpsa_upload_endpoint

        """
        pass

    def test_create_vpsa_endpoints_conf_for_upload_types(self):
        """Test case for create_vpsa_endpoints_conf_for_upload_types

        """
        pass

    def test_create_zsnap(self):
        """Test case for create_zsnap

        """
        pass

    def test_delete_vpsa_endpoints_conf_for_upload_types(self):
        """Test case for delete_vpsa_endpoints_conf_for_upload_types

        """
        pass

    def test_delete_vpsa_upload_endpoint(self):
        """Test case for delete_vpsa_upload_endpoint

        """
        pass

    def test_disable_data_reduction_bundle_for_flash_vpsa(self):
        """Test case for disable_data_reduction_bundle_for_flash_vpsa

        """
        pass

    def test_disable_flc(self):
        """Test case for disable_flc

        """
        pass

    def test_disable_pool_migration_for_all_flash_array_vpsa(self):
        """Test case for disable_pool_migration_for_all_flash_array_vpsa

        """
        pass

    def test_enable_data_reduction_bundle_for_flash_vpsa(self):
        """Test case for enable_data_reduction_bundle_for_flash_vpsa

        """
        pass

    def test_enable_flc(self):
        """Test case for enable_flc

        """
        pass

    def test_enable_pool_migration(self):
        """Test case for enable_pool_migration

        """
        pass

    def test_failover_vpsa(self):
        """Test case for failover_vpsa

        """
        pass

    def test_get_all_vpsa_drives(self):
        """Test case for get_all_vpsa_drives

        """
        pass

    def test_get_all_vpsas(self):
        """Test case for get_all_vpsas

        """
        pass

    def test_get_raid_groups(self):
        """Test case for get_raid_groups

        """
        pass

    def test_get_vpsa_capacity_trend(self):
        """Test case for get_vpsa_capacity_trend

        """
        pass

    def test_get_vpsa_endpoint_configs_by_upload_types(self):
        """Test case for get_vpsa_endpoint_configs_by_upload_types

        """
        pass

    def test_get_vpsa_from_cloud(self):
        """Test case for get_vpsa_from_cloud

        """
        pass

    def test_get_vpsa_settings(self):
        """Test case for get_vpsa_settings

        """
        pass

    def test_hibrenate_vpsa(self):
        """Test case for hibrenate_vpsa

        """
        pass

    def test_list_all_vpsa_upload_endpoints(self):
        """Test case for list_all_vpsa_upload_endpoints

        """
        pass

    def test_list_availiable_virtual_nets_to_add_vpsa(self):
        """Test case for list_availiable_virtual_nets_to_add_vpsa

        """
        pass

    def test_list_vpsas_comments(self):
        """Test case for list_vpsas_comments

        """
        pass

    def test_list_vpsas_pools(self):
        """Test case for list_vpsas_pools

        """
        pass

    def test_list_vpsas_vc(self):
        """Test case for list_vpsas_vc

        """
        pass

    def test_list_vpsas_virtual_nets(self):
        """Test case for list_vpsas_virtual_nets

        """
        pass

    def test_manage_vpsa_recycle_bin(self):
        """Test case for manage_vpsa_recycle_bin

        """
        pass

    def test_move_virtual_net_to_diff_sn(self):
        """Test case for move_virtual_net_to_diff_sn

        """
        pass

    def test_purge_vpsa_from_recycle_bin(self):
        """Test case for purge_vpsa_from_recycle_bin

        """
        pass

    def test_release_networks_from_vpsa(self):
        """Test case for release_networks_from_vpsa

        """
        pass

    def test_remove_virtual_network_interface(self):
        """Test case for remove_virtual_network_interface

        """
        pass

    def test_reschedule_upgrade_vpsa(self):
        """Test case for reschedule_upgrade_vpsa

        """
        pass

    def test_restore_vpsa(self):
        """Test case for restore_vpsa

        """
        pass

    def test_resume_upgrade(self):
        """Test case for resume_upgrade

        """
        pass

    def test_unassign_public_ip(self):
        """Test case for unassign_public_ip

        """
        pass

    def test_update_cloud_vpsas_status(self):
        """Test case for update_cloud_vpsas_status

        """
        pass

    def test_update_vpsa_status(self):
        """Test case for update_vpsa_status

        """
        pass

    def test_update_vpsa_upload_endpoint(self):
        """Test case for update_vpsa_upload_endpoint

        """
        pass

    def test_upgrade_vpsa_version(self):
        """Test case for upgrade_vpsa_version

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class AttachServersToVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'volume_name': 'str',
        'access_type': 'str',
        'lun': 'int',
        'readonly': 'str',
        'force': 'str'
    }

    attribute_map = {
        'volume_name': 'volume_name',
        'access_type': 'access_type',
        'lun': 'lun',
        'readonly': 'readonly',
        'force': 'force'
    }

    def __init__(self, volume_name=None, access_type=None, lun=None, readonly=None, force=None, _configuration=None):  # noqa: E501
        """AttachServersToVolume - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._volume_name = None
        self._access_type = None
        self._lun = None
        self._readonly = None
        self._force = None
        self.discriminator = None

        self.volume_name = volume_name
        if access_type is not None:
            self.access_type = access_type
        if lun is not None:
            self.lun = lun
        if readonly is not None:
            self.readonly = readonly
        if force is not None:
            self.force = force

    @property
    def volume_name(self):
        """Gets the volume_name of this AttachServersToVolume.  # noqa: E501

        The volume ID.  # noqa: E501

        :return: The volume_name of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._volume_name

    @volume_name.setter
    def volume_name(self, volume_name):
        """Sets the volume_name of this AttachServersToVolume.

        The volume ID.  # noqa: E501

        :param volume_name: The volume_name of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and volume_name is None:
            raise ValueError("Invalid value for `volume_name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                volume_name is not None and not re.search(r'^volume-[0-9a-f]{8}$', volume_name)):  # noqa: E501
            raise ValueError(r"Invalid value for `volume_name`, must be a follow pattern or equal to `/^volume-[0-9a-f]{8}$/`")  # noqa: E501

        self._volume_name = volume_name

    @property
    def access_type(self):
        """Gets the access_type of this AttachServersToVolume.  # noqa: E501

        NFS/SMB for NAS, ISCSI for Block.  # noqa: E501

        :return: The access_type of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this AttachServersToVolume.

        NFS/SMB for NAS, ISCSI for Block.  # noqa: E501

        :param access_type: The access_type of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        allowed_values = ["NFS", "SMB", "ISCSI"]  # noqa: E501
        if (self._configuration.client_side_validation and
                access_type not in allowed_values):
            raise ValueError(
                "Invalid value for `access_type` ({0}), must be one of {1}"  # noqa: E501
                .format(access_type, allowed_values)
            )

        self._access_type = access_type

    @property
    def lun(self):
        """Gets the lun of this AttachServersToVolume.  # noqa: E501


        :return: The lun of this AttachServersToVolume.  # noqa: E501
        :rtype: int
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this AttachServersToVolume.


        :param lun: The lun of this AttachServersToVolume.  # noqa: E501
        :type: int
        """

        self._lun = lun

    @property
    def readonly(self):
        """Gets the readonly of this AttachServersToVolume.  # noqa: E501

        Relevant only to NFS/SMB  # noqa: E501

        :return: The readonly of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._readonly

    @readonly.setter
    def readonly(self, readonly):
        """Sets the readonly of this AttachServersToVolume.

        Relevant only to NFS/SMB  # noqa: E501

        :param readonly: The readonly of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                readonly not in allowed_values):
            raise ValueError(
                "Invalid value for `readonly` ({0}), must be one of {1}"  # noqa: E501
                .format(readonly, allowed_values)
            )

        self._readonly = readonly

    @property
    def force(self):
        """Gets the force of this AttachServersToVolume.  # noqa: E501

        Required only when volume is already attached to another server.  # noqa: E501

        :return: The force of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this AttachServersToVolume.

        Required only when volume is already attached to another server.  # noqa: E501

        :param force: The force of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                force not in allowed_values):
            raise ValueError(
                "Invalid value for `force` ({0}), must be one of {1}"  # noqa: E501
                .format(force, allowed_values)
            )

        self._force = force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AttachServersToVolume, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachServersToVolume):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttachServersToVolume):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200230ResponseServers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'iqn': 'str',
        'iscsi_ip': 'str',
        'ipsec': 'str',
        'status': 'str',
        'os': 'str',
        'registered': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'pm_status': 'str',
        'target': 'str',
        'access_type': 'str',
        'read_only': 'str',
        'lun': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'iqn': 'iqn',
        'iscsi_ip': 'iscsi_ip',
        'ipsec': 'ipsec',
        'status': 'status',
        'os': 'os',
        'registered': 'registered',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'pm_status': 'pm_status',
        'target': 'target',
        'access_type': 'access_type',
        'read_only': 'read_only',
        'lun': 'lun'
    }

    def __init__(self, name=None, display_name=None, iqn=None, iscsi_ip=None, ipsec=None, status=None, os=None, registered=None, created_at=None, modified_at=None, pm_status=None, target=None, access_type=None, read_only=None, lun=None, _configuration=None):  # noqa: E501
        """InlineResponse200230ResponseServers - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._iqn = None
        self._iscsi_ip = None
        self._ipsec = None
        self._status = None
        self._os = None
        self._registered = None
        self._created_at = None
        self._modified_at = None
        self._pm_status = None
        self._target = None
        self._access_type = None
        self._read_only = None
        self._lun = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if iqn is not None:
            self.iqn = iqn
        if iscsi_ip is not None:
            self.iscsi_ip = iscsi_ip
        if ipsec is not None:
            self.ipsec = ipsec
        if status is not None:
            self.status = status
        if os is not None:
            self.os = os
        if registered is not None:
            self.registered = registered
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if pm_status is not None:
            self.pm_status = pm_status
        if target is not None:
            self.target = target
        if access_type is not None:
            self.access_type = access_type
        if read_only is not None:
            self.read_only = read_only
        if lun is not None:
            self.lun = lun

    @property
    def name(self):
        """Gets the name of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The name of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200230ResponseServers.


        :param name: The name of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The display_name of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200230ResponseServers.


        :param display_name: The display_name of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def iqn(self):
        """Gets the iqn of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The iqn of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._iqn

    @iqn.setter
    def iqn(self, iqn):
        """Sets the iqn of this InlineResponse200230ResponseServers.


        :param iqn: The iqn of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._iqn = iqn

    @property
    def iscsi_ip(self):
        """Gets the iscsi_ip of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The iscsi_ip of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_ip

    @iscsi_ip.setter
    def iscsi_ip(self, iscsi_ip):
        """Sets the iscsi_ip of this InlineResponse200230ResponseServers.


        :param iscsi_ip: The iscsi_ip of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._iscsi_ip = iscsi_ip

    @property
    def ipsec(self):
        """Gets the ipsec of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The ipsec of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._ipsec

    @ipsec.setter
    def ipsec(self, ipsec):
        """Sets the ipsec of this InlineResponse200230ResponseServers.


        :param ipsec: The ipsec of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._ipsec = ipsec

    @property
    def status(self):
        """Gets the status of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The status of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200230ResponseServers.


        :param status: The status of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def os(self):
        """Gets the os of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The os of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this InlineResponse200230ResponseServers.


        :param os: The os of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._os = os

    @property
    def registered(self):
        """Gets the registered of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The registered of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._registered

    @registered.setter
    def registered(self, registered):
        """Sets the registered of this InlineResponse200230ResponseServers.


        :param registered: The registered of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._registered = registered

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The created_at of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200230ResponseServers.


        :param created_at: The created_at of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The modified_at of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200230ResponseServers.


        :param modified_at: The modified_at of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def pm_status(self):
        """Gets the pm_status of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The pm_status of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._pm_status

    @pm_status.setter
    def pm_status(self, pm_status):
        """Sets the pm_status of this InlineResponse200230ResponseServers.


        :param pm_status: The pm_status of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._pm_status = pm_status

    @property
    def target(self):
        """Gets the target of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The target of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this InlineResponse200230ResponseServers.


        :param target: The target of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def access_type(self):
        """Gets the access_type of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The access_type of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this InlineResponse200230ResponseServers.


        :param access_type: The access_type of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._access_type = access_type

    @property
    def read_only(self):
        """Gets the read_only of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The read_only of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this InlineResponse200230ResponseServers.


        :param read_only: The read_only of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._read_only = read_only

    @property
    def lun(self):
        """Gets the lun of this InlineResponse200230ResponseServers.  # noqa: E501


        :return: The lun of this InlineResponse200230ResponseServers.  # noqa: E501
        :rtype: str
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this InlineResponse200230ResponseServers.


        :param lun: The lun of this InlineResponse200230ResponseServers.  # noqa: E501
        :type: str
        """

        self._lun = lun

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200230ResponseServers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200230ResponseServers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200230ResponseServers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.logs_api import LogsApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestLogsApi(unittest.TestCase):
    """LogsApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.logs_api.LogsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_address_to_remote_rsyslog_server_list(self):
        """Test case for add_address_to_remote_rsyslog_server_list

        """
        pass

    def test_delete_address_from_remote_rsyslog_server_list(self):
        """Test case for delete_address_from_remote_rsyslog_server_list

        """
        pass

    def test_list_recent_event(self):
        """Test case for list_recent_event

        """
        pass

    def test_retrieve_address_of_remote_rsyslog_server_list(self):
        """Test case for retrieve_address_of_remote_rsyslog_server_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdatePoolCapacityAlerts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capacityhistory': 'int',
        'effectivecapacityhistory': 'int',
        'alertmode': 'int',
        'effectivealertmode': 'int',
        'protectedmode': 'int',
        'effectiveprotectedmode': 'int',
        'emergencymode': 'int',
        'effectiveemergencymode': 'int'
    }

    attribute_map = {
        'capacityhistory': 'capacityhistory',
        'effectivecapacityhistory': 'effectivecapacityhistory',
        'alertmode': 'alertmode',
        'effectivealertmode': 'effectivealertmode',
        'protectedmode': 'protectedmode',
        'effectiveprotectedmode': 'effectiveprotectedmode',
        'emergencymode': 'emergencymode',
        'effectiveemergencymode': 'effectiveemergencymode'
    }

    def __init__(self, capacityhistory=None, effectivecapacityhistory=None, alertmode=None, effectivealertmode=None, protectedmode=None, effectiveprotectedmode=None, emergencymode=None, effectiveemergencymode=None, _configuration=None):  # noqa: E501
        """UpdatePoolCapacityAlerts - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._capacityhistory = None
        self._effectivecapacityhistory = None
        self._alertmode = None
        self._effectivealertmode = None
        self._protectedmode = None
        self._effectiveprotectedmode = None
        self._emergencymode = None
        self._effectiveemergencymode = None
        self.discriminator = None

        if capacityhistory is not None:
            self.capacityhistory = capacityhistory
        if effectivecapacityhistory is not None:
            self.effectivecapacityhistory = effectivecapacityhistory
        if alertmode is not None:
            self.alertmode = alertmode
        if effectivealertmode is not None:
            self.effectivealertmode = effectivealertmode
        if protectedmode is not None:
            self.protectedmode = protectedmode
        if effectiveprotectedmode is not None:
            self.effectiveprotectedmode = effectiveprotectedmode
        if emergencymode is not None:
            self.emergencymode = emergencymode
        if effectiveemergencymode is not None:
            self.effectiveemergencymode = effectiveemergencymode

    @property
    def capacityhistory(self):
        """Gets the capacityhistory of this UpdatePoolCapacityAlerts.  # noqa: E501

        Window size in minutes which is used to calculate the rate of which free Pool capacity is consumed. This rate is used to calculate the estimated time until a Pool is full.  # noqa: E501

        :return: The capacityhistory of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._capacityhistory

    @capacityhistory.setter
    def capacityhistory(self, capacityhistory):
        """Sets the capacityhistory of this UpdatePoolCapacityAlerts.

        Window size in minutes which is used to calculate the rate of which free Pool capacity is consumed. This rate is used to calculate the estimated time until a Pool is full.  # noqa: E501

        :param capacityhistory: The capacityhistory of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._capacityhistory = capacityhistory

    @property
    def effectivecapacityhistory(self):
        """Gets the effectivecapacityhistory of this UpdatePoolCapacityAlerts.  # noqa: E501

        Window size in minutes which is used to calculate the rate of which free Pool effective capacity is consumed. This rate is used to calculate the estimated time until a Pool is full.  # noqa: E501

        :return: The effectivecapacityhistory of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._effectivecapacityhistory

    @effectivecapacityhistory.setter
    def effectivecapacityhistory(self, effectivecapacityhistory):
        """Sets the effectivecapacityhistory of this UpdatePoolCapacityAlerts.

        Window size in minutes which is used to calculate the rate of which free Pool effective capacity is consumed. This rate is used to calculate the estimated time until a Pool is full.  # noqa: E501

        :param effectivecapacityhistory: The effectivecapacityhistory of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._effectivecapacityhistory = effectivecapacityhistory

    @property
    def alertmode(self):
        """Gets the alertmode of this UpdatePoolCapacityAlerts.  # noqa: E501

        Send an alert when it is estimated that the Pool will be at full capacity in this many minutes.  # noqa: E501

        :return: The alertmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._alertmode

    @alertmode.setter
    def alertmode(self, alertmode):
        """Sets the alertmode of this UpdatePoolCapacityAlerts.

        Send an alert when it is estimated that the Pool will be at full capacity in this many minutes.  # noqa: E501

        :param alertmode: The alertmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._alertmode = alertmode

    @property
    def effectivealertmode(self):
        """Gets the effectivealertmode of this UpdatePoolCapacityAlerts.  # noqa: E501

        Send an alert when it is estimated that the Pool will be at full effective capacity in this many minutes.  # noqa: E501

        :return: The effectivealertmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._effectivealertmode

    @effectivealertmode.setter
    def effectivealertmode(self, effectivealertmode):
        """Sets the effectivealertmode of this UpdatePoolCapacityAlerts.

        Send an alert when it is estimated that the Pool will be at full effective capacity in this many minutes.  # noqa: E501

        :param effectivealertmode: The effectivealertmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._effectivealertmode = effectivealertmode

    @property
    def protectedmode(self):
        """Gets the protectedmode of this UpdatePoolCapacityAlerts.  # noqa: E501

        Block Volume/Share/Pool creation when it's estimated that the Pool will be full in this many minutes.  # noqa: E501

        :return: The protectedmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._protectedmode

    @protectedmode.setter
    def protectedmode(self, protectedmode):
        """Sets the protectedmode of this UpdatePoolCapacityAlerts.

        Block Volume/Share/Pool creation when it's estimated that the Pool will be full in this many minutes.  # noqa: E501

        :param protectedmode: The protectedmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._protectedmode = protectedmode

    @property
    def effectiveprotectedmode(self):
        """Gets the effectiveprotectedmode of this UpdatePoolCapacityAlerts.  # noqa: E501

        Block Volume/Share/Pool creation when it's estimated that the Pool effective capacity will be full in this many minutes.  # noqa: E501

        :return: The effectiveprotectedmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._effectiveprotectedmode

    @effectiveprotectedmode.setter
    def effectiveprotectedmode(self, effectiveprotectedmode):
        """Sets the effectiveprotectedmode of this UpdatePoolCapacityAlerts.

        Block Volume/Share/Pool creation when it's estimated that the Pool effective capacity will be full in this many minutes.  # noqa: E501

        :param effectiveprotectedmode: The effectiveprotectedmode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._effectiveprotectedmode = effectiveprotectedmode

    @property
    def emergencymode(self):
        """Gets the emergencymode of this UpdatePoolCapacityAlerts.  # noqa: E501

        Delete snapshots, starting with the oldest, when the Pool has less than this number of GB left.  # noqa: E501

        :return: The emergencymode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._emergencymode

    @emergencymode.setter
    def emergencymode(self, emergencymode):
        """Sets the emergencymode of this UpdatePoolCapacityAlerts.

        Delete snapshots, starting with the oldest, when the Pool has less than this number of GB left.  # noqa: E501

        :param emergencymode: The emergencymode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._emergencymode = emergencymode

    @property
    def effectiveemergencymode(self):
        """Gets the effectiveemergencymode of this UpdatePoolCapacityAlerts.  # noqa: E501

        Delete snapshots, starting with the oldest, when the Pool effective capacity has less than this number of GB left.  # noqa: E501

        :return: The effectiveemergencymode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :rtype: int
        """
        return self._effectiveemergencymode

    @effectiveemergencymode.setter
    def effectiveemergencymode(self, effectiveemergencymode):
        """Sets the effectiveemergencymode of this UpdatePoolCapacityAlerts.

        Delete snapshots, starting with the oldest, when the Pool effective capacity has less than this number of GB left.  # noqa: E501

        :param effectiveemergencymode: The effectiveemergencymode of this UpdatePoolCapacityAlerts.  # noqa: E501
        :type: int
        """

        self._effectiveemergencymode = effectiveemergencymode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdatePoolCapacityAlerts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePoolCapacityAlerts):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdatePoolCapacityAlerts):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20027DataPubliczios(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'vpsa_id': 'int',
        'account_name': 'str',
        'username': 'str',
        'ip': 'str',
        'host': 'str',
        'auto_approve': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'vpsa_id': 'vpsa_id',
        'account_name': 'account_name',
        'username': 'username',
        'ip': 'ip',
        'host': 'host',
        'auto_approve': 'auto_approve'
    }

    def __init__(self, id=None, vpsa_id=None, account_name=None, username=None, ip=None, host=None, auto_approve=None, _configuration=None):  # noqa: E501
        """InlineResponse20027DataPubliczios - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._vpsa_id = None
        self._account_name = None
        self._username = None
        self._ip = None
        self._host = None
        self._auto_approve = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if vpsa_id is not None:
            self.vpsa_id = vpsa_id
        if account_name is not None:
            self.account_name = account_name
        if username is not None:
            self.username = username
        if ip is not None:
            self.ip = ip
        if host is not None:
            self.host = host
        if auto_approve is not None:
            self.auto_approve = auto_approve

    @property
    def id(self):
        """Gets the id of this InlineResponse20027DataPubliczios.  # noqa: E501


        :return: The id of this InlineResponse20027DataPubliczios.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20027DataPubliczios.


        :param id: The id of this InlineResponse20027DataPubliczios.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def vpsa_id(self):
        """Gets the vpsa_id of this InlineResponse20027DataPubliczios.  # noqa: E501


        :return: The vpsa_id of this InlineResponse20027DataPubliczios.  # noqa: E501
        :rtype: int
        """
        return self._vpsa_id

    @vpsa_id.setter
    def vpsa_id(self, vpsa_id):
        """Sets the vpsa_id of this InlineResponse20027DataPubliczios.


        :param vpsa_id: The vpsa_id of this InlineResponse20027DataPubliczios.  # noqa: E501
        :type: int
        """

        self._vpsa_id = vpsa_id

    @property
    def account_name(self):
        """Gets the account_name of this InlineResponse20027DataPubliczios.  # noqa: E501


        :return: The account_name of this InlineResponse20027DataPubliczios.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this InlineResponse20027DataPubliczios.


        :param account_name: The account_name of this InlineResponse20027DataPubliczios.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def username(self):
        """Gets the username of this InlineResponse20027DataPubliczios.  # noqa: E501


        :return: The username of this InlineResponse20027DataPubliczios.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this InlineResponse20027DataPubliczios.


        :param username: The username of this InlineResponse20027DataPubliczios.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def ip(self):
        """Gets the ip of this InlineResponse20027DataPubliczios.  # noqa: E501


        :return: The ip of this InlineResponse20027DataPubliczios.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this InlineResponse20027DataPubliczios.


        :param ip: The ip of this InlineResponse20027DataPubliczios.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def host(self):
        """Gets the host of this InlineResponse20027DataPubliczios.  # noqa: E501


        :return: The host of this InlineResponse20027DataPubliczios.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this InlineResponse20027DataPubliczios.


        :param host: The host of this InlineResponse20027DataPubliczios.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def auto_approve(self):
        """Gets the auto_approve of this InlineResponse20027DataPubliczios.  # noqa: E501


        :return: The auto_approve of this InlineResponse20027DataPubliczios.  # noqa: E501
        :rtype: bool
        """
        return self._auto_approve

    @auto_approve.setter
    def auto_approve(self, auto_approve):
        """Sets the auto_approve of this InlineResponse20027DataPubliczios.


        :param auto_approve: The auto_approve of this InlineResponse20027DataPubliczios.  # noqa: E501
        :type: bool
        """

        self._auto_approve = auto_approve

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20027DataPubliczios, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20027DataPubliczios):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20027DataPubliczios):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreatePool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'capacity': 'str',
        'cache': 'str',
        'cowcache': 'bool',
        'mode': 'str',
        'raid_groups': 'str',
        'pooltype': 'str'
    }

    attribute_map = {
        'display_name': 'display_name',
        'capacity': 'capacity',
        'cache': 'cache',
        'cowcache': 'cowcache',
        'mode': 'mode',
        'raid_groups': 'raid_groups',
        'pooltype': 'pooltype'
    }

    def __init__(self, display_name=None, capacity=None, cache='NO', cowcache=True, mode='simple', raid_groups=None, pooltype=None, _configuration=None):  # noqa: E501
        """CreatePool - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._display_name = None
        self._capacity = None
        self._cache = None
        self._cowcache = None
        self._mode = None
        self._raid_groups = None
        self._pooltype = None
        self.discriminator = None

        self.display_name = display_name
        self.capacity = capacity
        if cache is not None:
            self.cache = cache
        if cowcache is not None:
            self.cowcache = cowcache
        if mode is not None:
            self.mode = mode
        self.raid_groups = raid_groups
        if pooltype is not None:
            self.pooltype = pooltype

    @property
    def display_name(self):
        """Gets the display_name of this CreatePool.  # noqa: E501

        The new pool display name  # noqa: E501

        :return: The display_name of this CreatePool.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreatePool.

        The new pool display name  # noqa: E501

        :param display_name: The display_name of this CreatePool.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def capacity(self):
        """Gets the capacity of this CreatePool.  # noqa: E501

        The new pool capacity followed by the letter G  # noqa: E501

        :return: The capacity of this CreatePool.  # noqa: E501
        :rtype: str
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this CreatePool.

        The new pool capacity followed by the letter G  # noqa: E501

        :param capacity: The capacity of this CreatePool.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and capacity is None:
            raise ValueError("Invalid value for `capacity`, must not be `None`")  # noqa: E501

        self._capacity = capacity

    @property
    def cache(self):
        """Gets the cache of this CreatePool.  # noqa: E501

        Indicate whether the Pool will utilize the VPSA SSD cache. All Pools marked YES share the same cache capacity.  # noqa: E501

        :return: The cache of this CreatePool.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this CreatePool.

        Indicate whether the Pool will utilize the VPSA SSD cache. All Pools marked YES share the same cache capacity.  # noqa: E501

        :param cache: The cache of this CreatePool.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                cache not in allowed_values):
            raise ValueError(
                "Invalid value for `cache` ({0}), must be one of {1}"  # noqa: E501
                .format(cache, allowed_values)
            )

        self._cache = cache

    @property
    def cowcache(self):
        """Gets the cowcache of this CreatePool.  # noqa: E501

        Indicate whether snapshot Copy-On-Write operations are Cached. Default: YES  # noqa: E501

        :return: The cowcache of this CreatePool.  # noqa: E501
        :rtype: bool
        """
        return self._cowcache

    @cowcache.setter
    def cowcache(self, cowcache):
        """Sets the cowcache of this CreatePool.

        Indicate whether snapshot Copy-On-Write operations are Cached. Default: YES  # noqa: E501

        :param cowcache: The cowcache of this CreatePool.  # noqa: E501
        :type: bool
        """

        self._cowcache = cowcache

    @property
    def mode(self):
        """Gets the mode of this CreatePool.  # noqa: E501

        Indicate whether RAID groups are concatinated or striped inside the Pool.  # noqa: E501

        :return: The mode of this CreatePool.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this CreatePool.

        Indicate whether RAID groups are concatinated or striped inside the Pool.  # noqa: E501

        :param mode: The mode of this CreatePool.  # noqa: E501
        :type: str
        """
        allowed_values = ["stripe", "simple"]  # noqa: E501
        if (self._configuration.client_side_validation and
                mode not in allowed_values):
            raise ValueError(
                "Invalid value for `mode` ({0}), must be one of {1}"  # noqa: E501
                .format(mode, allowed_values)
            )

        self._mode = mode

    @property
    def raid_groups(self):
        """Gets the raid_groups of this CreatePool.  # noqa: E501

        Comma separated list of RAID Group IDs.  # noqa: E501

        :return: The raid_groups of this CreatePool.  # noqa: E501
        :rtype: str
        """
        return self._raid_groups

    @raid_groups.setter
    def raid_groups(self, raid_groups):
        """Sets the raid_groups of this CreatePool.

        Comma separated list of RAID Group IDs.  # noqa: E501

        :param raid_groups: The raid_groups of this CreatePool.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and raid_groups is None:
            raise ValueError("Invalid value for `raid_groups`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                raid_groups is not None and not re.search(r'(?:RaidGroup-[0-9]+[,]?)+', raid_groups)):  # noqa: E501
            raise ValueError(r"Invalid value for `raid_groups`, must be a follow pattern or equal to `/(?:RaidGroup-[0-9]+[,]?)+/`")  # noqa: E501

        self._raid_groups = raid_groups

    @property
    def pooltype(self):
        """Gets the pooltype of this CreatePool.  # noqa: E501

        The new pool type. VPSA Storage Array: Repository Storage, Transactional Workloads, Archival Storage, Depot Storage. VPSA Flash Array: IOPs-Optimized, Balanced, Throughput-Optimized.  # noqa: E501

        :return: The pooltype of this CreatePool.  # noqa: E501
        :rtype: str
        """
        return self._pooltype

    @pooltype.setter
    def pooltype(self, pooltype):
        """Sets the pooltype of this CreatePool.

        The new pool type. VPSA Storage Array: Repository Storage, Transactional Workloads, Archival Storage, Depot Storage. VPSA Flash Array: IOPs-Optimized, Balanced, Throughput-Optimized.  # noqa: E501

        :param pooltype: The pooltype of this CreatePool.  # noqa: E501
        :type: str
        """
        allowed_values = ["Transactional Workloads", "Repository Storage", "Archival Storage", "IOPs-Optimized", "Balanced", "Throughput-Optimized", "Depot", "Depot Storage"]  # noqa: E501
        if (self._configuration.client_side_validation and
                pooltype not in allowed_values):
            raise ValueError(
                "Invalid value for `pooltype` ({0}), must be one of {1}"  # noqa: E501
                .format(pooltype, allowed_values)
            )

        self._pooltype = pooltype

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreatePool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePool):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreatePool):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class AddNewUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'username': 'str',
        'email': 'str',
        'account_id': 'str',
        'notify_on_events': 'str',
        'role': 'str'
    }

    attribute_map = {
        'username': 'username',
        'email': 'email',
        'account_id': 'account_id',
        'notify_on_events': 'notify_on_events',
        'role': 'role'
    }

    def __init__(self, username=None, email=None, account_id=None, notify_on_events=None, role=None, _configuration=None):  # noqa: E501
        """AddNewUser - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._username = None
        self._email = None
        self._account_id = None
        self._notify_on_events = None
        self._role = None
        self.discriminator = None

        self.username = username
        self.email = email
        self.account_id = account_id
        if notify_on_events is not None:
            self.notify_on_events = notify_on_events
        self.role = role

    @property
    def username(self):
        """Gets the username of this AddNewUser.  # noqa: E501

        The new username  # noqa: E501

        :return: The username of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this AddNewUser.

        The new username  # noqa: E501

        :param username: The username of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def email(self):
        """Gets the email of this AddNewUser.  # noqa: E501

        The new user email  # noqa: E501

        :return: The email of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AddNewUser.

        The new user email  # noqa: E501

        :param email: The email of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def account_id(self):
        """Gets the account_id of this AddNewUser.  # noqa: E501

        Account ID  # noqa: E501

        :return: The account_id of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AddNewUser.

        Account ID  # noqa: E501

        :param account_id: The account_id of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and account_id is None:
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def notify_on_events(self):
        """Gets the notify_on_events of this AddNewUser.  # noqa: E501

        Notify the user on system events  # noqa: E501

        :return: The notify_on_events of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._notify_on_events

    @notify_on_events.setter
    def notify_on_events(self, notify_on_events):
        """Sets the notify_on_events of this AddNewUser.

        Notify the user on system events  # noqa: E501

        :param notify_on_events: The notify_on_events of this AddNewUser.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                notify_on_events not in allowed_values):
            raise ValueError(
                "Invalid value for `notify_on_events` ({0}), must be one of {1}"  # noqa: E501
                .format(notify_on_events, allowed_values)
            )

        self._notify_on_events = notify_on_events

    @property
    def role(self):
        """Gets the role of this AddNewUser.  # noqa: E501

        User role in account  # noqa: E501

        :return: The role of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this AddNewUser.

        User role in account  # noqa: E501

        :param role: The role of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["zios_admin", "account_admin", "member"]  # noqa: E501
        if (self._configuration.client_side_validation and
                role not in allowed_values):
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddNewUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddNewUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddNewUser):
            return True

        return self.to_dict() != other.to_dict()
